@@ -7,7 +7,7 @@ class Text:
         self.size_txt = renderer.get_size()
         self.tmp_pos = int()
 
-    def caclulate_pos(self):
+    def calculate_pos(self):
         if self.pos == "auto_XY":
             return (self.size_obj[0] // 2 - self.size_txt[0] // 2, self.size_obj[1] // 2 - self.size_txt[1] // 2 )
 
